## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
These are the payment tickets.
"""
import grok
from grok import index
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.sirp.payments.interfaces import (
    IPayment, ISCPayment, IOnlinePayment)
from waeup.sirp.utils.helpers import attrs_to_fields

class Payment(grok.Container):
    """This is a payment.
    """
    grok.implements(IPayment)
    grok.provides(IPayment)
    grok.baseclass()

    def __init__(self):
        super(Payment, self).__init__()
        return

class SCPayment(Payment):
    """This is a scratch card payment.
    """
    grok.implements(ISCPayment)
    grok.provides(ISCPayment)

    def __init__(self):
        super(SCPayment, self).__init__()
        return

SCPayment = attrs_to_fields(SCPayment)

class OnlinePayment(Payment):
    """This is an online payment.
    """
    grok.implements(IOnlinePayment)
    grok.provides(IOnlinePayment)

    def __init__(self):
        super(OnlinePayment, self).__init__()
        return

OnlinePayment = attrs_to_fields(OnlinePayment)

# Online payments must be importable. So we might need a factory.
class OnlinePaymentFactory(grok.GlobalUtility):
    """A factory for online payments.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.OnlinePayment')
    title = u"Create a new online payment.",
    description = u"This factory instantiates new online payment instances."

    def __call__(self, *args, **kw):
        return OnlinePayment()

    def getInterfaces(self):
        return implementedBy(OnlinePayment)
