## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Tests for payments.
"""
from zope.interface.verify import verifyClass, verifyObject
from waeup.sirp.payments.interfaces import (
    IPaymentsContainer, ISCPayment, IOnlinePayment)
from waeup.sirp.payments.container import PaymentsContainer
from waeup.sirp.payments.payment import (
    SCPayment, OnlinePayment, OnlinePaymentFactory)
from waeup.sirp.testing import (FunctionalLayer, FunctionalTestCase)

class PaymentsContainerTestCase(FunctionalTestCase):

    layer = FunctionalLayer

    def test_interfaces(self):
        # Make sure the correct interfaces are implemented.
        self.assertTrue(
            verifyClass(
                IPaymentsContainer, PaymentsContainer)
            )
        self.assertTrue(
            verifyObject(
                IPaymentsContainer, PaymentsContainer())
            )
        self.assertTrue(
            verifyClass(
                ISCPayment, SCPayment)
            )
        self.assertTrue(
            verifyClass(
                IOnlinePayment, OnlinePayment)
            )
        self.assertTrue(
            verifyObject(
                ISCPayment, SCPayment())
            )
        self.assertTrue(
            verifyObject(
                IOnlinePayment, OnlinePayment())
            )
        return

    def test_base(self):
        # We cannot call the fundamental methods of a base in that case
        container = PaymentsContainer()
        self.assertRaises(
            NotImplementedError, container.archive)
        self.assertRaises(
            NotImplementedError, container.clear)

class OnlinePaymentFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(OnlinePaymentFactoryTest, self).setUp()
        self.factory = OnlinePaymentFactory()
        return

    def tearDown(self):
        super(OnlinePaymentFactoryTest, self).tearDown()
        return

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, OnlinePayment)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(IOnlinePayment)
